==> route53-1.60.0-sources.jar: software/amazon/awscdk/services/route53/RecordTarget.java <==
package software.amazon.awscdk.services.route53;

/**
 * Type union for a record that accepts multiple types of target.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.272Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.route53.$Module.class, fqn = "@aws-cdk/aws-route53.RecordTarget")
public class RecordTarget extends software.amazon.jsii.JsiiObject {

    protected RecordTarget(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected RecordTarget(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param values correspond with the chosen record type (e.g. for 'A' Type, specify one ore more IP addresses).
     * @param aliasTarget alias for targets such as CloudFront distribution to route traffic to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected RecordTarget(final @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> values, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.route53.IAliasRecordTarget aliasTarget) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { values, aliasTarget });
    }

    /**
     * @param values correspond with the chosen record type (e.g. for 'A' Type, specify one ore more IP addresses).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected RecordTarget(final @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> values) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { values });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected RecordTarget() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Use an alias as target.
     * <p>
     * @param aliasTarget This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.RecordTarget fromAlias(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.IAliasRecordTarget aliasTarget) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.route53.RecordTarget.class, "fromAlias", software.amazon.awscdk.services.route53.RecordTarget.class, new Object[] { java.util.Objects.requireNonNull(aliasTarget, "aliasTarget is required") });
    }

    /**
     * Use ip addresses as target.
     * <p>
     * @param ipAddresses This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.RecordTarget fromIpAddresses(final @org.jetbrains.annotations.NotNull java.lang.String... ipAddresses) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.route53.RecordTarget.class, "fromIpAddresses", software.amazon.awscdk.services.route53.RecordTarget.class, java.util.Arrays.<Object>stream(ipAddresses).toArray(Object[]::new));
    }

    /**
     * Use string values as target.
     * <p>
     * @param values This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.RecordTarget fromValues(final @org.jetbrains.annotations.NotNull java.lang.String... values) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.route53.RecordTarget.class, "fromValues", software.amazon.awscdk.services.route53.RecordTarget.class, java.util.Arrays.<Object>stream(values).toArray(Object[]::new));
    }

    /**
     * alias for targets such as CloudFront distribution to route traffic to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.route53.IAliasRecordTarget getAliasTarget() {
        return this.jsiiGet("aliasTarget", software.amazon.awscdk.services.route53.IAliasRecordTarget.class);
    }

    /**
     * correspond with the chosen record type (e.g. for 'A' Type, specify one ore more IP addresses).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getValues() {
        return java.util.Optional.ofNullable((java.util.List<java.lang.String>)(this.jsiiGet("values", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }
}

==> route53-1.100.0-sources.jar: software/amazon/awscdk/services/route53/RecordTarget.java <==
package software.amazon.awscdk.services.route53;

/**
 * Type union for a record that accepts multiple types of target.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:22.497Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.route53.$Module.class, fqn = "@aws-cdk/aws-route53.RecordTarget")
public class RecordTarget extends software.amazon.jsii.JsiiObject {

    protected RecordTarget(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected RecordTarget(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param values correspond with the chosen record type (e.g. for 'A' Type, specify one or more IP addresses).
     * @param aliasTarget alias for targets such as CloudFront distribution to route traffic to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected RecordTarget(final @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> values, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.route53.IAliasRecordTarget aliasTarget) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { values, aliasTarget });
    }

    /**
     * @param values correspond with the chosen record type (e.g. for 'A' Type, specify one or more IP addresses).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected RecordTarget(final @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> values) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { values });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected RecordTarget() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Use an alias as target.
     * <p>
     * @param aliasTarget This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.RecordTarget fromAlias(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.IAliasRecordTarget aliasTarget) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.route53.RecordTarget.class, "fromAlias", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.route53.RecordTarget.class), new Object[] { java.util.Objects.requireNonNull(aliasTarget, "aliasTarget is required") });
    }

    /**
     * Use ip addresses as target.
     * <p>
     * @param ipAddresses This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.RecordTarget fromIpAddresses(final @org.jetbrains.annotations.NotNull java.lang.String... ipAddresses) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.route53.RecordTarget.class, "fromIpAddresses", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.route53.RecordTarget.class), java.util.Arrays.<Object>stream(ipAddresses).toArray(Object[]::new));
    }

    /**
     * Use string values as target.
     * <p>
     * @param values This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.route53.RecordTarget fromValues(final @org.jetbrains.annotations.NotNull java.lang.String... values) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.route53.RecordTarget.class, "fromValues", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.route53.RecordTarget.class), java.util.Arrays.<Object>stream(values).toArray(Object[]::new));
    }

    /**
     * alias for targets such as CloudFront distribution to route traffic to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.route53.IAliasRecordTarget getAliasTarget() {
        return software.amazon.jsii.Kernel.get(this, "aliasTarget", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.route53.IAliasRecordTarget.class));
    }

    /**
     * correspond with the chosen record type (e.g. for 'A' Type, specify one or more IP addresses).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getValues() {
        return java.util.Optional.ofNullable((java.util.List<java.lang.String>)(software.amazon.jsii.Kernel.get(this, "values", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }
}
